package Bundle::WWW::Search::ALL;

$VERSION = '1.13';

1;

__END__

=head1 NAME

Bundle::WWW::Search::ALL - A bundle to install all WWW::Search modules and backends

=head1 SYNOPSIS

C<perl Makefile.PL>
C<make install>
C<perl -MCPAN -e 'install Bundle::WWW::Search::ALL'>

=head1 CONTENTS

Bundle::WWW::Search

WWW::Search::AlltheWeb

J/JS/JSMYSER/WWW-Search-AltaVista-AdvancedWeb-2.02.tar.gz

WWW::Search::Deja

J/JS/JSMYSER/WWW-Search-EuroSeek-1.03.tar.gz

WWW::Search::Excite

J/JS/JSMYSER/WWW-Search-Excite-News-2.04.tar.gz

WWW::Search::Go

J/JS/JSMYSER/WWW-Search-GoTo-1.07.tar.gz

J/JS/JSMYSER/WWW-Search-Google-2.21.tar.gz

WWW::Search::HotBot

J/JS/JSMYSER/WWW-Search-LookSmart-2.05.tar.gz

WWW::Search::Lycos

M/MT/MTHURN/WWW-Search-Magellan-2.06.tar.gz

J/JS/JSMYSER/WWW-Search-MetaCrawler-2.07.tar.gz

J/JS/JSMYSER/WWW-Search-News-2.05.tar.gz

WWW::Search::Nomade

J/JS/JSMYSER/WWW-Search-NorthernLight.-2.06.tar.gz

J/JS/JSMYSER/WWW-Search-OpenDirectory-2.02.tar.gz

WWW::Search::PRWire

WWW::Search::PubMed

J/JS/JSMYSER/WWW-Search-Snap-2.06.tar.gz

WWW::Search::Translator

J/JS/JSMYSER/WWW-Search-X-Search-1.06.tar.gz

M/MT/MTHURN/WWW-Search-Yahoo-2.18.tar.gz

WWW::Search::YahooNews

J/JS/JSMYSER/WWW-Search-ZDNet-2.02+.tar.gz

=head1 DESCRIPTION

This bundle gathers together all of the modules for WWW::Search,
including all the prerequisites and all the backends.

If you know of other backends or updated backends, please inform the
author:

=head1 AUTHOR

Martin Thurn E<lt>F<martinthurn@iname.com>E<gt>
(Author only of this bundle, not necessarily of the modules it lists)

=cut

